modules Package
===============

:mod:`modules` Package
----------------------

.. automodule:: numba.type_inference.modules
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`builtinmodule` Module
---------------------------

.. automodule:: numba.type_inference.modules.builtinmodule
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mathmodule` Module
------------------------

.. automodule:: numba.type_inference.modules.mathmodule
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numbamodule` Module
-------------------------

.. automodule:: numba.type_inference.modules.numbamodule
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numpymodule` Module
-------------------------

.. automodule:: numba.type_inference.modules.numpymodule
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`numpyufuncs` Module
-------------------------

.. automodule:: numba.type_inference.modules.numpyufuncs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: numba.type_inference.modules.utils
    :members:
    :undoc-members:
    :show-inheritance:

